<template>
  <gree-popup v-model="isShow" position="bottom" @hide="hidePopup">
    <div class="swlfrig-set-popup">
      <!-- 标题 -->
      <div class="swlfrig-set-popup-title" v-text="swlfrig" />
      <div class="sweep-body">
        <gree-sweep-select
          :canvas-id="canvasId1"
          :canvas-width="width1"
          :canvas-height="height1"
          :origin="origin1"
          :select-default="selectDefault"
          @change="sweepLrChangeHandler"
          v-if="touchId === 1"
        ></gree-sweep-select>
      </div>
    </div>
  </gree-popup>
</template>

<script>
import { Header, SweepSelect, Toast, Popup } from 'gree-ui';
import { mapState, mapMutations, mapActions } from 'vuex';
import { showToast } from '@PluginInterface';
import { types } from '@/store/types';

export default {
  name: 'swlfrig-picker-popup',
  components: {
    [Header.name]: Header,
    [Popup.name]: Popup,
    [SweepSelect.name]: SweepSelect
  },
  data() {
    return {
      isShow: false,
      canvasId1: 'sector1',
      arr1: [],
      width1: Math.floor(window['lib'].flexible.rem / 0.1),
      height1: Math.floor(window['lib'].flexible.rem / 0.15561),
      origin1: {
        x: Math.floor(window['lib'].flexible.rem / 0.2),
        y: 0,
        r: Math.floor(window['lib'].flexible.rem / 0.16461),
        startdeg: 135,
        opendeg: 18,
        count: 5
      },
      selectDefault: ['0'],

      touchId: 1 // 1：左右扫风 2：上下扫风
    };
  },
  computed: {
    ...mapState('control', {
      SwUpDnPicker: state => state.popup.SwUpDnPicker,
      SwLfRigPicker: state => state.popup.SwLfRigPicker,
      SwingLfRig: state => state.dataObject.SwingLfRig,
      SwUpDn: state => state.dataObject.SwUpDn,
      Pow: state => state.dataObject.Pow,
      selectSwingLfRig: state => {
        const swingLfRig = state.dataObject.SwingLfRig;
        const swingLfRigMap = [[], [], ['1'], ['2'], ['3'], ['4'], ['5']];
        return swingLfRigMap[swingLfRig];
      },
      selectSwUpDn: state => {
        const swUpDn = state.dataObject.SwUpDn;
        const swUpDnMap = [[], [], ['1'], ['2'], ['3'], ['4'], ['5']];
        return swUpDnMap[swUpDn];
      }
    }),
    routeName() {
      return this.$route.name;
    },
    swlfrig() {
      return this.$language('btn.ConstLR');
    }
  },
  watch: {
    SwLfRigPicker: {
      handler(newVal) {
        this.isShow = newVal;
      },
      immediate: true
    },
    isShow(newVal) {
      !newVal && this.SetPopup({ SwLfRigPicker: false });
    },
    SwingLfRig: {
      handler(newVal) {
        if (newVal) {
          this.selectDefault = this.selectSwingLfRig;
          this.touchId = 0;
          this.$nextTick(() => (this.touchId = 1));
        }
      }
    },
    selectSwingLfRig(newVal) {
      const touchId = this.$route.params.id;
      if (touchId === 1) {
        this.selectDefault = newVal;
        this.touchId = 0;
        this.$nextTick(() => (this.touchId = touchId));
      }
    }
  },
  methods: {
    ...mapMutations({
      setDataObject: types.SET_DATA_OBJECT,
      setState: types.CONTROL_SET_STATE
    }),
    ...mapMutations('control', {
      SetPopup: 'SET_POPUP'
    }),
    ...mapActions({
      sendCtrl: types.SEND_CTRL
    }),
    turnBack() {
      this.$router.push({ name: 'Home' }).catch(err => {
        err;
      });
    },
    hidePopup() {
      this.SetPopup({ SwLfRigPicker: false });
    },
    sweepLrChangeHandler(val) {
      const val2 = [];
      val.forEach(item => {
        val2.indexOf(item) === -1 ? val2.push(item) : '';
      });
      if (val2) {
        if (val2.length === 1) {
          this._setSweep({ SwingLfRig: Number(val2[0]) + 1, SmartWind: 0 });
        } else {
          // 刷新扇叶
          this.selectDefault = this.selectSwingLfRig;
          this.touchId = 0;
          this.$nextTick(() => (this.touchId = 1));
          try {
            val2.length && showToast(this.$language('sweep.sweep_lr_tips'), 0);
          } catch (err) {
            val2.length && Toast.info(`${this.$language('sweep.sweep_lr_tips')}`);
          }
        }
      }
    },
    sweepUdChangeHandler(val) {
      const val2 = [];
      val.forEach(item => {
        val2.indexOf(item) === -1 ? val2.push(item) : '';
      });
      if (val2) {
        if (val2.length === 1) {
          this._setSweep({ SwUpDn: Number(val2[0]) + 1, SmartWind: 0 });
        } else {
          // 刷新扇叶
          this.selectDefault = this.selectSwUpDn;
          this.touchId = 0;
          this.$nextTick(() => (this.touchId = 2));
          try {
            val2.length && showToast(this.$language('sweep.sweep_ud_tips2'), 0);
          } catch (err) {
            val2.length && Toast.info(`${this.$language('sweep.sweep_ud_tips2')}`);
          }
        }
      }
    },
    _setSweep(data) {
      if (!data) {
        return;
      }
      const storage = window.storage;
      const funcData = storage.get('funcData') || {};
      if (typeof data.SwingLfRig !== 'undefined' && this.SwingLfRig !== data.SwingLfRig) {
        this.setState({ ableSend: true });
        this.setDataObject({ ...data, SmartWind: 0 });
        this.sendCtrl({ ...data, SmartWind: 0 });
        funcData.ConstLR = data.SwingLfRig;
        storage.set('funcData', funcData);
      }

      if (typeof data.SwUpDn !== 'undefined' && this.SwUpDn !== data.SwUpDn) {
        this.setState({ ableSend: true });
        this.setDataObject({ ...data, SmartWind: 0, AntiDirectBlow: 0 });
        this.sendCtrl({ ...data, SmartWind: 0, AntiDirectBlow: 0 });
        funcData.ConstUD = data.SwUpDn;
        storage.set('funcData', funcData);
      }
    }
  }
};
</script>

<style lang="scss">
.swlfrig-set-popup {
  width: 100%;
  background-color: #fff;
  &-title {
    padding-top: 30px;
    text-align: center;
    font-size: 50px;
  }
  .sweep-body {
    height: 950px;
  }
  canvas {
    position: relative;
    opacity: 0 !important;
  }
  .sweep-select-horizontal {
    margin: 0 auto;
    top: 100px;
    width: 1080px;
    height: 686px;
    background-image: url('../../assets/img/functionBtn/sweep/sweep_horizontal.png');
    background-repeat: no-repeat;
    background-size: contain;
    background-position: center;

    .selected {
      position: absolute;
      background-repeat: no-repeat;
      background-size: contain;
      background-position: center;
      pointer-events: none;

      &-1 {
        top: 8px;
        left: 70px;
        width: 484px;
        height: 631px;
        background-image: url('../../assets/img/functionBtn/sweep/sweep_horizontal_1.png');
        background-size: 96%;
      }

      &-2 {
        top: 25px;
        left: 237px;
        width: 310px;
        height: 651px;
        background-image: url('../../assets/img/functionBtn/sweep/sweep_horizontal_2.png');
      }

      &-3 {
        top: 20px;
        left: 431px;
        width: 219px;
        height: 673px;
        background-image: url('../../assets/img/functionBtn/sweep/sweep_horizontal_3.png');
      }

      &-4 {
        top: 10px;
        left: 527px;
        width: 316px;
        height: 681px;
        background-image: url('../../assets/img/functionBtn/sweep/sweep_horizontal_4.png');
      }

      &-5 {
        top: 24px;
        left: 530px;
        width: 476px;
        height: 589px;
        background-image: url('../../assets/img/functionBtn/sweep/sweep_horizontal_5.png');
      }
    }
  }
}
</style>
